aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/includes/compatibility_globals.php
diff options
context:
space:
mode:
authorMateBartus <mate.bartus@gmail.com>2015-04-28 15:49:07 +0200
committerMate Bartus <mate.bartus@gmail.com>2015-07-08 01:27:55 +0200
commit5afc632bcaee256811942b442d244ef284d1eff6 (patch)
tree068671824457ac2beb367b10727a4dba71d29442 /phpBB/includes/compatibility_globals.php
parent14e8f712ae0278afff2a750b707dfd66f6e13182 (diff)
downloadforums-5afc632bcaee256811942b442d244ef284d1eff6.tar
forums-5afc632bcaee256811942b442d244ef284d1eff6.tar.gz
forums-5afc632bcaee256811942b442d244ef284d1eff6.tar.bz2
forums-5afc632bcaee256811942b442d244ef284d1eff6.tar.xz
forums-5afc632bcaee256811942b442d244ef284d1eff6.zip
[ticket/13740] Core file workarounds
[ci skip] PHPBB3-13740
Diffstat (limited to 'phpBB/includes/compatibility_globals.php')
-rw-r--r--phpBB/includes/compatibility_globals.php99
1 files changed, 58 insertions, 41 deletions
diff --git a/phpBB/includes/compatibility_globals.php b/phpBB/includes/compatibility_globals.php
index 5c18793655..cb4087d09b 100644
--- a/phpBB/includes/compatibility_globals.php
+++ b/phpBB/includes/compatibility_globals.php
@@ -1,62 +1,79 @@
<?php
/**
-*
-* This file is part of the phpBB Forum Software package.
-*
-* @copyright (c) phpBB Limited <https://www.phpbb.com>
-* @license GNU General Public License, version 2 (GPL-2.0)
-*
-* For full copyright and license information, please see
-* the docs/CREDITS.txt file.
-*
-*/
+ *
+ * This file is part of the phpBB Forum Software package.
+ *
+ * @copyright (c) phpBB Limited <https://www.phpbb.com>
+ * @license GNU General Public License, version 2 (GPL-2.0)
+ *
+ * For full copyright and license information, please see
+ * the docs/CREDITS.txt file.
+ *
+ */
/**
-*/
+ */
if (!defined('IN_PHPBB'))
{
exit;
}
-// set up caching
-/* @var $cache \phpbb\cache\service */
-$cache = $phpbb_container->get('cache');
+/**
+ * Sets compatibility globals in the global scope
+ *
+ * This function registers compatibility variables to the global
+ * variable scope. This is required to make it possible to include this file
+ * in a service.
+ */
+function register_compatibility_globals()
+{
+ global $phpbb_container;
+
+ global $cache, $phpbb_dispatcher, $request, $user, $auth, $db, $config, $phpbb_log;
+ global $symfony_request, $phpbb_filesystem, $phpbb_path_helper, $phpbb_extension_manager, $template;
-// Instantiate some basic classes
-/* @var $phpbb_dispatcher \phpbb\event\dispatcher */
-$phpbb_dispatcher = $phpbb_container->get('dispatcher');
+ // set up caching
+ /* @var $cache \phpbb\cache\service */
+ $cache = $phpbb_container->get('cache');
-/* @var $request \phpbb\request\request_interface */
-$request = $phpbb_container->get('request');
+ // Instantiate some basic classes
+ /* @var $phpbb_dispatcher \phpbb\event\dispatcher */
+ $phpbb_dispatcher = $phpbb_container->get('dispatcher');
-/* @var $user \phpbb\user */
-$user = $phpbb_container->get('user');
+ /* @var $request \phpbb\request\request_interface */
+ $request = $phpbb_container->get('request');
-/* @var $auth \phpbb\auth\auth */
-$auth = $phpbb_container->get('auth');
+ /* @var $user \phpbb\user */
+ $user = $phpbb_container->get('user');
-/* @var $db \phpbb\db\driver\driver_interface */
-$db = $phpbb_container->get('dbal.conn');
+ /* @var $auth \phpbb\auth\auth */
+ $auth = $phpbb_container->get('auth');
-// Grab global variables, re-cache if necessary
-/* @var $config phpbb\config\db */
-$config = $phpbb_container->get('config');
+ /* @var $db \phpbb\db\driver\driver_interface */
+ $db = $phpbb_container->get('dbal.conn');
-/* @var $phpbb_log \phpbb\log\log_interface */
-$phpbb_log = $phpbb_container->get('log');
+ // Grab global variables, re-cache if necessary
+ /* @var $config phpbb\config\db */
+ $config = $phpbb_container->get('config');
-/* @var $symfony_request \phpbb\symfony_request */
-$symfony_request = $phpbb_container->get('symfony_request');
+ /* @var $phpbb_log \phpbb\log\log_interface */
+ $phpbb_log = $phpbb_container->get('log');
-/* @var $phpbb_filesystem \phpbb\filesystem\filesystem_interface */
-$phpbb_filesystem = $phpbb_container->get('filesystem');
+ /* @var $symfony_request \phpbb\symfony_request */
+ $symfony_request = $phpbb_container->get('symfony_request');
-/* @var $phpbb_path_helper \phpbb\path_helper */
-$phpbb_path_helper = $phpbb_container->get('path_helper');
+ /* @var $phpbb_filesystem \phpbb\filesystem\filesystem_interface */
+ $phpbb_filesystem = $phpbb_container->get('filesystem');
-// load extensions
-/* @var $phpbb_extension_manager \phpbb\extension\manager */
-$phpbb_extension_manager = $phpbb_container->get('ext.manager');
+ /* @var $phpbb_path_helper \phpbb\path_helper */
+ $phpbb_path_helper = $phpbb_container->get('path_helper');
+
+ // load extensions
+ /* @var $phpbb_extension_manager \phpbb\extension\manager */
+ $phpbb_extension_manager = $phpbb_container->get('ext.manager');
+
+ /* @var $template \phpbb\template\template */
+ $template = $phpbb_container->get('template');
+}
-/* @var $template \phpbb\template\template */
-$template = $phpbb_container->get('template');
+register_compatibility_globals();